import logging
from django.core.management.base import BaseCommand, CommandError
from django_pyres.conf import settings

from optparse import make_option
from pyres.worker import Worker
from pyres import setup_logging, setup_pidfile

class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('-l', '--log-level', dest='log_level', default='info', help='log level.  Valid values are "debug", "info", "warning", "error", "critical", in decreasing order of verbosity. Defaults to "info" if parameter not specified.'),
    )
    help = 'Creates a pyres worker'

    def handle(self, queue_list, **options):
        queues = queue_list.split(',')
        log_level = getattr(logging, options['log_level'].upper(), 'INFO')
        setup_logging(procname="pyres_worker", log_level=log_level, filename=None)
        setup_pidfile(settings.PYRES_WORKER_PIDFILE)
        interval = settings.PYRES_WORKER_INTERVAL
        worker = Worker(
            queues=queues,
            server=settings.PYRES_HOST,
            password=settings.PYRES_PASSWORD,
            timeout=settings.PYRES_WORKER_TIMEOUT
        )
        if interval is not None:
            worker.work(interval)
        else:
            worker.work()




from pyres import ResQ
from django.conf import settings
pyres = ResQ(getattr(settings,'PYRES_HOST','localhost:6379'),getattr(settings,'PYRES_PASSWORD',None))

class PyresMixin(object):
    @classmethod
    def enqueue(cls, *args):
        if settings.PYRES_USE_QUEUE:
            pyres.enqueue(cls, *args)
        else:
            cls.perform(*args)



"""
This file demonstrates writing tests using the unittest module. These will pass
when you run "manage.py test".

Replace this with more appropriate tests for your application.
"""

from django.test import TestCase
from django_pyres.decorators import job
from mock import patch
import redis

def sample_function(*args):
    return args

class DecoratorTest(TestCase):

    def setUp(self):
        self.decorated_function = job('test')(sample_function)

    def test_decoration(self):
        self.assertIsNotNone(getattr(self.decorated_function, 'perform'))
        self.assertIsNotNone(getattr(self.decorated_function, 'enqueue'))
        self.assertEqual(self.decorated_function.queue, 'test')
        self.assertTrue(callable(self.decorated_function))
        self.assertEqual(self.decorated_function.__name__, sample_function.__name__)

    def test_call(self):
        self.assertEqual(self.decorated_function(1, 2, 3, 4), (1, 2, 3, 4))

    @patch.object(redis.Redis, 'execute_command')
    def test_enqueue(self, MockRedis):
        self.decorated_function.enqueue('test', 'this')
        self.assertTrue(MockRedis.called)



import os
from setuptools import setup, find_packages
version=__import__('django_pyres').__version__
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()
setup(
    name='django-pyres',
    version=version,
    description='django pyres integration',
    long_description=read('README.txt'),
    author='Matt George',
    author_email='mgeorge@gmail.com',
    maintainer='Matt George',
    license='BSD',
    url='http://github.com/Pyres/django_pyres',
    packages=find_packages(exclude=['ez_setup', 'example','testapp','tests']),
    package_data={'': ['README.txt']},
    include_package_data=True,
    install_requires=[
        'pyres>=1.4.1',
        'django-appconf>=0.5'
    ],
    classifiers = [
            'Development Status :: 4 - Beta',
            'Environment :: Console',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: MIT License',
            'Operating System :: OS Independent',
            'Programming Language :: Python'],
)

